@@ -35,6 +35,7 @@ NSString *const VLCPlaybackServicePlaybackMetadataDidChange = @"VLCPlaybackServi
 NSString *const VLCPlaybackServicePlaybackDidFail = @"VLCPlaybackServicePlaybackDidFail";
 NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackServicePlaybackPositionUpdated";
 NSString *const VLCPlaybackServicePlaybackModeUpdated = @"VLCPlaybackServicePlaybackModeUpdated";
+NSString *const VLCPlaybackServicePlaybackDidMoveOnToNextItem = @"VLCPlaybackServicePlaybackDidMoveOnToNextItem";
 
 #if TARGET_OS_IOS
 @interface VLCPlaybackService () <VLCMediaPlayerDelegate, VLCMediaDelegate, VLCMediaListPlayerDelegate, EqualizerViewDelegate>
@@ -531,6 +532,7 @@ NSString *const VLCPlaybackServicePlaybackModeUpdated = @"VLCPlaybackServicePlay
 
 - (BOOL)isNextMediaAvailable
 {
+    NSLog(@"%s", __func__);
     if (_mediaList.count == 1) {
         return NO;
     }
@@ -825,6 +827,7 @@ NSString *const VLCPlaybackServicePlaybackModeUpdated = @"VLCPlaybackServicePlay
     VLCMedia *media = [_mediaList mediaAtIndex:index];
     [_listPlayer playItemAtNumber:[NSNumber numberWithUnsignedInteger:index]];
     _mediaPlayer.media = media;
+    _currentIndex = [_mediaList indexOfMedia:media];
     if ([self.delegate respondsToSelector:@selector(prepareForMediaPlayback:)])
         [self.delegate prepareForMediaPlayback:self];
 }
@@ -869,6 +872,7 @@ NSString *const VLCPlaybackServicePlaybackModeUpdated = @"VLCPlaybackServicePlay
 {
     int mediaListCount = (int) _mediaList.count;
 
+    NSInteger nextIndex = 0;
     if (!_currentIndex) {
         _currentIndex = [_mediaList indexOfMedia:self.currentlyPlayingMedia];
     }
@@ -879,26 +883,30 @@ NSString *const VLCPlaybackServicePlaybackModeUpdated = @"VLCPlaybackServicePlay
         if ([self.delegate respondsToSelector:@selector(playModeUpdated)]) {
             [self.delegate playModeUpdated];
         }
+
         [[NSNotificationCenter defaultCenter] postNotificationName:VLCPlaybackServicePlaybackModeUpdated object:self];
     } else if (self.repeatMode == VLCRepeatCurrentItem && !isButtonPressed) {
         return _currentIndex;
     }
 
     // Normal playback
-    if(_currentIndex + 1 < mediaListCount) {
-        _currentIndex += 1;
+    if (_currentIndex + 1 < mediaListCount) {
+        nextIndex = _currentIndex + 1;
     } else {
-        if(self.repeatMode == VLCRepeatAllItems) {
-            _currentIndex = 0;
+        if (self.repeatMode == VLCRepeatAllItems) {
+            nextIndex = 0;
         } else {
-            return -1;
+            nextIndex = -1;
         }
     }
+
     if (_shuffleMode && mediaListCount > 2) {
-        return [_shuffledOrder[_currentIndex] integerValue];
-    } else {
-        return _currentIndex;
+        nextIndex = [_shuffledOrder[_currentIndex] integerValue];
     }
+
+    _currentIndex = nextIndex;
+
+    return _currentIndex;
 }
 
 - (BOOL)next
@@ -919,6 +927,8 @@ NSString *const VLCPlaybackServicePlaybackModeUpdated = @"VLCPlaybackServicePlay
             [_listPlayer next];
             [[NSNotificationCenter defaultCenter]
              postNotificationName:VLCPlaybackServicePlaybackMetadataDidChange object:self];
+        } else if (self.repeatMode == VLCDoNotRepeat) {
+            [self stopPlayback];
         }
         return NO;
     }
@@ -1624,6 +1634,9 @@ NSString *const VLCPlaybackServicePlaybackModeUpdated = @"VLCPlaybackServicePlay
     if ([_delegate respondsToSelector:@selector(playbackService:nextMedia:)]) {
         [_delegate playbackService:self nextMedia:media];
     }
+
+    [[NSNotificationCenter defaultCenter] postNotificationName:VLCPlaybackServicePlaybackDidMoveOnToNextItem
+                                                        object:self];
 }
 
 @end
